@@ -1,10 +1,12 @@
 package App::SmokeBrew::Plugin;
+{
+  $App::SmokeBrew::Plugin::VERSION = '0.46';
+}
+
+#ABSTRACT: A Moose role for smokebrew plugins
 
 use strict;
 use warnings;
-use vars qw[$VERSION];
-
-$VERSION = '0.44';
 
 use Moose::Role;
 use Moose::Util::TypeConstraints;
@@ -72,10 +74,16 @@ qq[Smokin'];
 
 __END__
 
+=pod
+
 =head1 NAME
 
 App::SmokeBrew::Plugin - A Moose role for smokebrew plugins
 
+=head1 VERSION
+
+version 0.46
+
 =head1 SYNOPSIS
 
   package App::SmokeBrew::Plugin::Some::Plugin;
@@ -158,16 +166,6 @@ L<App::SmokeBrew> will pass any options it finds in a named section of the confi
 plugin when it a new plugin instance. See L<smokebrew> for details. You are expected to document any options
 that may be passed to your plugin in this manner.
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<smokebrew>
@@ -178,4 +176,15 @@ L<MooseX::Types::Email>
 
 L<MooseX::Types::Path::Class>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
