@@ -1,10 +1,12 @@
 package App::SmokeBrew::Plugin::Null;
+{
+  $App::SmokeBrew::Plugin::Null::VERSION = '0.46';
+}
+
+#ABSTRACT: A smokebrew plugin for does nothing.
 
 use strict;
 use warnings;
-use vars qw[$VERSION];
-
-$VERSION = '0.44';
 
 use Moose;
 
@@ -22,10 +24,16 @@ qq[Smokin'];
 
 __END__
 
+=pod
+
 =head1 NAME
 
 App::SmokeBrew::Plugin::Null - A smokebrew plugin for does nothing.
 
+=head1 VERSION
+
+version 0.46
+
 =head1 SYNOPSIS
 
   smokebrew --plugin App::SmokeBrew::Plugin::Null
@@ -46,16 +54,6 @@ Returns true as soon as it is called.
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<App::SmokeBrew::Plugin>
@@ -66,4 +64,15 @@ L<CPANPLUS>
 
 L<CPANPLUS::YACSmoke>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
